@@ -528,11 +528,22 @@ impl ProcessMemory {
         self.pid
     }
 
+    /// Retrieve the size of the first section/module
     #[cfg(target_os = "macos")]
     pub fn base_size(&self) -> usize {
         self.base_size
     }
 
+    /// Retrieve a raw handle/task port, or the PID for Linux as ptrace(2) does not use file descriptors
+    pub fn raw_descriptor(&self) -> usize {
+        #[cfg(any(target_os = "macos", target_family = "windows"))] {
+            self.handle
+        }
+        #[cfg(target_vendor = "unknown")] {
+            self.pid as _
+        }
+    }
+
     /// This will close the handles/task ports or detach from a ptrace(2) session, making the ProcessMemory object effectively useless with the exception of retaining data.
     pub fn early_close(&mut self) {
         #[cfg(target_family = "windows")]
